<?php
/**
 * ###############################################
 *
 * SWIFT Framework
 * _______________________________________________
 *
 * @author         Varun Shoor
 *
 * @package        SWIFT
 * @copyright      Copyright (c) 2001-2012, Kayako
 * @license        http://www.kayako.com/license
 * @link           http://www.kayako.com
 *
 * ###############################################
 */

/**
 * SugarCRM Account Model
 *
 * @author Rahul Bhattacharya
 */
class SWIFT_SugarCRMAccount extends SWIFT_Model
{
    // Table Name
    const TABLE_NAME = 'userorganizations';

    /**
     * Constructor
     *
     * return boolean True on Success, or False Otherwise
     *
     * @author Rahul Bhattacharya
     */
    public function __construct()
    {
        parent::__construct();

        return true;
    }


    /**
     * Destructor
     *
     * return boolean True on Success, or False Otherwise
     *
     * @author Rahul Bhattacharya
     */
    public function __destruct()
    {
        parent::__destruct();

        return true;
    }


    /**
     * Responsible to insert the sugarcrm account data
     *
     * @param $_postArray
     *
     * @return bool
     *
     * @author Rahul Bhattacharya
     */
    public function InsertOrganizations($_postArray)
    {
        if (self::CheckOrganizationExistence($_postArray['id'])) {
            $_SWIFT = SWIFT::GetInstance();

            $_SWIFT->Database->AutoExecute(TABLE_PREFIX . self::TABLE_NAME, array(
                'organizationname' => $_SWIFT->Database->Escape($_postArray['name']),
                'address'          => $_SWIFT->Database->Escape($_postArray['billing_address_street']),
                'city'             => $_SWIFT->Database->Escape($_postArray['billing_address_city']),
                'state'            => $_SWIFT->Database->Escape($_postArray['billing_address_state']),
                'postalcode'       => intval($_postArray['billing_address_postalcode']),
                'country'          => $_SWIFT->Database->Escape($_postArray['billing_address_country']),
                'phone'            => $_SWIFT->Database->Escape($_postArray['phone_office']),
                'website'          => $_SWIFT->Database->Escape($_postArray['website']),
                'dateline'         => strtotime($_SWIFT->Database->Escape($_postArray['date_entered'])),
                'lastupdate'       => strtotime($_SWIFT->Database->Escape($_postArray['date_modified'])),
                'organizationtype' => '1'
            ), 'INSERT');

            $_lastInsertID = $_SWIFT->Database->Insert_ID();

            $_SWIFT->Database->AutoExecute(TABLE_PREFIX . 'sugarcrmaccountinfo', array(
                'accountid'       => $_SWIFT->Database->Escape($_postArray['id']),
                'parentaccountid' => $_SWIFT->Database->Escape($_lastInsertID)
            ), 'INSERT');
        }

        return true;
    }

	/**
	 * Responsible for checking accountid from swsugarcrmaccountinfo table
	 *
	 * @param $_organizationId
	 *
	 * @param string $_column
	 *
	 * @return bool
	 *
	 * @author Rahul Bhattacharya
	 */
    static public function CheckOrganizationExistence($_organizationId, $_column = 'accountid')
    {
        //query to fetch the sugar account id from swsugarcrmaccountinfo
        $_SWIFT = SWIFT::GetInstance();
        $_SWIFT->Database->Query("SELECT * FROM " . TABLE_PREFIX . "sugarcrmaccountinfo WHERE " . $_column . " = '" . $_organizationId . "'");
        while ($_SWIFT->Database->NextRecord()) {
            $_sugarcrmAccountInfoId = $_SWIFT->Database->Record['sugarcrmaccountinfoid'];
        }

        if (!isset($_sugarcrmAccountInfoId)) {
            return true;
        }

        return false;
    }

    /**
     * Get the list of organizations
     *
     * @return array
     *
     * @author Rahul Bhattacharya
     */
    public function FetchOrganizations()
    {
        $_SWIFT = SWIFT::GetInstance();
        $_SWIFT->Database->Query("SELECT * FROM " . TABLE_PREFIX . "sugarcrmaccountinfo");
        $_sugarAccountList = array();
        $_count            = 0;
        while ($_SWIFT->Database->NextRecord()) {
            $_sugarAccountList[$_count]['accountid']       = $this->Database->Record['accountid'];
            $_sugarAccountList[$_count]['parentaccountid'] = $this->Database->Record['parentaccountid'];
            $_count++;
        }

        return $_sugarAccountList;
    }

    /**
     * Responsible for fetching parentaccountid from swsugarcrmaccountinfo table
     *
     * @param int  $_organizationId
     *
     * @param bool $_organizationName
     *
     * @return int
     *
     * @author Rahul Bhattacharya
     */
    public function getParentAccountId($_organizationId, $_organizationName = false)
    {
        //query to fetch the sugar account id from swsugarcrmaccountinfo
        $_SWIFT = SWIFT::GetInstance();

        if ($_organizationName) {
            $_SWIFT->Database->Query("SELECT userorganizationid FROM " . TABLE_PREFIX . self::TABLE_NAME . " WHERE organizationname Like '" . $_organizationId . "'");
            while ($_SWIFT->Database->NextRecord()) {
                $_parentAccountId = $this->Database->Record['userorganizationid'];
            }
        } else {
            $_SWIFT->Database->Query("SELECT parentaccountid FROM " . TABLE_PREFIX . "sugarcrmaccountinfo WHERE accountid = '" . $_organizationId . "'");
            while ($_SWIFT->Database->NextRecord()) {
                $_parentAccountId = $this->Database->Record['parentaccountid'];
            }
        }

        if (isset($_parentAccountId)) {
            return $_parentAccountId;
        }

        return 0;
    }
}